.TH TEXGRAPH L

.SH NAME
texgraph - converts a two-column data file into a file of
.I TeX
macros which are compatible with the package
.I pshacks.sty.

.SH SYNOPSIS
texgraph
.I [foo(.dat)]

.SH DESCRIPTION
.I texgraph
reads a file
.I foo.dat
(default is standard input) which contains lines formatted as
.HP
x[*]y
.P
where [*] can be any combination of spaces and one or less commas.  The
values in this file are the x-y data points for the graph.
.P
The entries are then processed and the user is asked to enter parameters for
the plot.  If the data was read from standard input, the parameters have to
be entered this way as well.  If the file
.I tginp.tginp
is present, the parameters will be read from it.  If this file is not present,
.I texgraph
next looks for
.I foo.tginp
from which to read the plotting parameters.  If this file is not present, the
parameters are read from standard input.
.P
The plotting parameters entered by the user are:
.HP
- The coordinates of the corners of the plot in graph coordinates.
.HP
- A flag indicating whether the user wants the graph axis to be of the same
scale.
.HP
- A flag indicating which axis will have its length set by the user (if the
axes are chosen to have the same scale).
.HP
- A flag indicating whether the user wants the axes scaled according to the
Golden Ratio.
.HP
- A flag indicating whether the user wants a tall graph or a short graph (if
the axes are chosen to be scaled by the Golden Ratio).
.HP
- The size of the plot in centimetres.  This will entail entering one or two
numbers depending on whether the user has selected the axes to have the same
scale or whether the user has selected the axes to be scaled according to the
Golden Ratio.
.HP
- A flag to indicate whether the points should be connected.
.HP
- A flag to indicate whether there should be arrows on the plot (if the lines
are connected).
.HP
- An indication of which direction the arrows should point (if arrows are
being used).
.HP
- The spacing of the arrows in data points (if arrows are being used).
.HP
- A flag to indicate if symbols are to be placed on the plot.
.HP
- The spacing of the symbols in data points (if symbols are being used).
.P
.I texgraph
will prompt the user for the parameters, so the above steps should be clear
in use.  When the parameters are entered,
.I texgraph
will write a bunch of
.I TeX
macros to a file
.I foo.tex
(or to standard output if the data was read from standard input).

.SH LaTeX COMMANDS
The commands in
.I foo.tex
will be interpreted by the
.LaTeX
package
.I pshacks.sty.
If you have chosen to plot symbols at points along the graph (see the plotting
parameters above), you must define the
.I TeX
macro "\\graphsymbol" to be the symbol you want.  For example,
.P
\\newcommand\\graphsymbol{\\htext{$+$}}
.P
will place a plus sign at the specified points.  And, of course, the
whole point behind using
.I texgraph
is that you can use
.I TeX
macros to make the labels and ticks on your plot.  For some hints in this
direction, see the
.I LaTeX
documentation for
.I texgraph.

.SH FILES
.TP 2.2i
.I %%binpath-name%%/texgraph
executable script.
.TP 2.2i
.I %%doc-name%%
.I LaTeX
documentation file.
.TP 2.2i
.I %%style-dir%%/pshacks.sty
.I LaTeX
macro file used by
.I texgraph.

.SH SEE ALSO
latex(1), tex(1)

.SH DIAGNOSTICS
After
.I texgraph
has written
.I foo.tex,
a log file,
.I foo.tglog,
is created which simply records all the information you entered as
plotting parameters, plus a few other things.

.SH AUTHOR
Andrew D. Lewis, Queen's University, Kingston, ON, Canada,
<andrew@mast.queensu.ca>.
